Commands and Syntax
===================================

Commands and syntax available for Wilfred. Documentation is automatically generated from source code using `sphinx-click <https://github.com/click-contrib/sphinx-click>`__

.. click:: wilfred.wilfred:cli
  :prog: wilfred
  :nested: full
